@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: project-template
 version: 0.2.0
-id: project-template-0.2.0-0ebb1cce2ec2d08df15ffddfdf2f6c6b
-key: proje_6fptC5TJhHPGycOZmBa8sO
+id: project-template-0.2.0-5f22bf7fb56ba29cfb440dc2c2b0a984
+key: proje_LityNPX97Yv0g6ifoB81GC
 license: BSD3
 maintainer: michael@fpcomplete.com
 homepage: https://github.com/fpco/haskell-ide
@@ -19,18 +19,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
-hs-libraries: HSproject-template-0.2.0-6fptC5TJhHPGycOZmBa8sO
+hs-libraries: HSproject-template-0.2.0-LityNPX97Yv0g6ifoB81GC
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
